OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "seconds ago" : "Sekunden zuvor",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Apps" : "Apps",
    "General" : "Allgemein",
    "Search" : "Suche",
    "Help" : "Hilfe",
    "Settings" : "Einstellungen",
    "Users" : "Benutzer",
    "__language_name__" : "Deutsch (Österreich)"
},
"nplurals=2; plural=(n != 1);");
